---
title: 다날 채널설정방법
category: 결제서비스 (채널설정 및 이용안내) > 채널설정 > 채널설정
seo:
  title: 다날 채널설정방법
  description: >-
    다날 연동을 위한 채널설정 방법을 안내드립니다. '테스트 연동, 실 연동' 순으로 이뤄지며, 결제대행사와 연동방식별로 설정하는 정보는
    상이할 수 있습니다.
  keywords:
    - 다날
    - 일반결제
    - 정기결제
    - 본인인증
    - 결제연동
    - 채널설정방법
    - 채널추가
tags:
  - 다날
  - 결제
  - 본인인증
  - 채널설정방법
pgCompanies:
  - 다날
searchTags:
  - 다날
  - 다날 테스트연동
  - 다날 테스트모드
  - 다날 실연동
  - 다날 실모드
  - 다날 일반결제
  - 다날 정기결제
  - 다날 결제실패
  - 테스트연동
  - 테스트결제
  - 실연동
  - 채널추가
  - 결제연동
  - 본인인증
  - 다날본인인증
  - 휴대폰본인인증
datetime: 2024-02-22T15:00:00.000Z
---

<Callout content="결제 연동을 위한 채널 설정 방법을 안내해 드립니다.
결제 연동을 위해서 채널설정은 필수이며 결제대행사와 연동방식별로 설정하는 정보는 상이할 수 있습니다.
또한 채널 설정 없이 결제 연동을 하실 경우 정상적인 호출이 불가하며, 오류가 발생됩니다." />

<Highlight url="#7_결제창-휴대폰결제-및-휴대폰-본인인증" text="다날 휴대폰 결제 및 본인인증 설정 바로가기 ↓" />

## <Highlight text="결제창 일반/정기결제" />

- 포트원 결제모듈 V1에서만 지원됩니다.

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout content="1. 일반결제(신용카드,계좌이체,가상계좌) 모듈과 휴대폰 소액결제 모듈이 구분되어있어 별도로 설정이 필요합니다.
2. 다날 테스트 모드의 경우 실제 결제 승인이 이루어지지만, PG사에서 일괄적으로 매일 자정이전 자동 취소가 이루어집니다.
3. 다날 정책상 계좌이체/가상계좌는 테스트 결제가 제공되지 않습니다.
4, 계약 후 실제 상점아이디로 테스트 하실 수 있습니다.테스트 모드에서 부분취소 테스트는 불가합니다." title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 다날
  - 결제모듈 : 결제창 일반/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) 클릭
  - 일반결제 / 정기결제 : 9810030929 선택
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

결제대행사와의 모든 계약을 마친 후 원천사(카드사. 은행 등)의 심사가 진행됩니다. 실 연동을 위한 특징은 아래 가이드를 통해 확인하실 수 있습니다.

- [실 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/real?page=1)

<Callout content="1. 가상계좌와 실시간 계좌이체의 암호화 key는 동일하므로 포트원 관리자콘솔 내 설정시 같은 항목에 한번만 설정해주시기 바랍니다.
2. **다날 가상계좌는 다날PG사 정책상 환불 서비스를 지원하지 않습니다.**
" title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 :  실 연동
  - 결제대행사 : 다날
  - 결제모듈 : 결제창 일반/정기결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디(CPID) : 다날로부터 발급받으신 상점아이디(CPID)
- CPPWD : **공란 (중요)**
- 신용카드 암호화 KEY : 다날로부터 발급받으신 카드 PWD
- 계좌이체/가상계좌 암호화 KEY : 다날로부터 발급받으신 계좌이체/가상계좌 PWD
  (계좌이체, 가상계좌 두가지 모두 이용하신다면 같은 값이 발급됩니다)
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

## <Highlight text="결제창 휴대폰 결제 및 휴대폰 본인인증" />

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout content="1. 일반결제(신용카드,계좌이체,가상계좌) 모듈과 **휴대폰소액결제** 모듈이 구분되어 있어 별도로 설정이 필요합니다.
2. 다날 테스트 모드의 경우 실제 결제 승인이 이루어지지만, PG사에서 일괄적으로 매일 자정이전 자동 취소가 이루어집니다.
3. 다날 정책상 **본인인증 테스트 연동정보가 제공되지 않습니다** 계약 후 실제 상점아이디로 테스트 하실 수 있습니다.
" title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 다날
  - 결제모듈 :  결제창 휴대폰 결제 및 휴대폰 본인인증

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) 클릭
  - 결제창 일반결제 - 휴대폰소액결제 A010002002 선택
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

결제대행사와의 모든 계약을 마친 후 원천사(카드사. 은행 등)의 심사가 진행됩니다. 실 연동을 위한 특징은 아래 가이드를 통해 확인하실 수 있습니다.

- [실 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/real?page=1)



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 다날
  - 결제모듈 :  결제창 휴대폰결제 및 휴대폰 본인인증

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (MID) : 다날로부터 발급받으신 상점아이디(CPID)
- CPPWD : 다날로부터 발급받은 PWD
- 상품코드 : 다날로부터 발급받은 상품코드
- 과세설정 : [포트원 결제사정산 서비스↗](https://admin.portone.io/reconciliation/summary) 이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 결 여부와는 관계없습니다.

<Callout title="V1 다날 개발가이드 보러가기↗" />

<Callout title="V1 다날 본인인증 개발가이드 보러가기↗" />

<Callout title="V2 다날 본인인증 개발가이드 보러가기↗" />
